svn commit: r215990 - in head/sys: contrib/octeon-sdk contrib/octeon-sdk/cvmx-malloc mips/cavium mips/cavium/octe

Juli Mallett jmallett at FreeBSD.org
Sun Nov 28 08:18:17 UTC 2010


Author: jmallett
Date: Sun Nov 28 08:18:16 2010
New Revision: 215990
URL: http://svn.freebsd.org/changeset/base/215990

Log:
  Merge Cavium Octeon SDK 2.0 Simple Executive; this brings some fixes and new
  facilities as well as support for the Octeon 2 family of SoCs.
  
  XXX Note that with our antediluvian assembler, we can't support some Octeon 2
      instructions and fall back to using the old ones instead.

Added:
  head/sys/contrib/octeon-sdk/cvmx-agl-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-agl-defs.h
  head/sys/contrib/octeon-sdk/cvmx-app-hotplug.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-app-hotplug.c
  head/sys/contrib/octeon-sdk/cvmx-app-hotplug.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-app-hotplug.h
  head/sys/contrib/octeon-sdk/cvmx-asx0-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-asx0-defs.h
  head/sys/contrib/octeon-sdk/cvmx-asxx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-asxx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-ciu-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-ciu-defs.h
  head/sys/contrib/octeon-sdk/cvmx-clock.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-clock.c
  head/sys/contrib/octeon-sdk/cvmx-clock.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-clock.h
  head/sys/contrib/octeon-sdk/cvmx-crypto.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-crypto.c
  head/sys/contrib/octeon-sdk/cvmx-crypto.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-crypto.h
  head/sys/contrib/octeon-sdk/cvmx-dbg-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-dbg-defs.h
  head/sys/contrib/octeon-sdk/cvmx-debug-handler.S
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-debug-handler.S
  head/sys/contrib/octeon-sdk/cvmx-debug-remote.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-debug-remote.c
  head/sys/contrib/octeon-sdk/cvmx-debug-uart.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-debug-uart.c
  head/sys/contrib/octeon-sdk/cvmx-debug.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-debug.c
  head/sys/contrib/octeon-sdk/cvmx-debug.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-debug.h
  head/sys/contrib/octeon-sdk/cvmx-dfa-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-dfa-defs.h
  head/sys/contrib/octeon-sdk/cvmx-dfm-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-dfm-defs.h
  head/sys/contrib/octeon-sdk/cvmx-dpi-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-dpi-defs.h
  head/sys/contrib/octeon-sdk/cvmx-error-custom.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-custom.c
  head/sys/contrib/octeon-sdk/cvmx-error-custom.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-custom.h
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn30xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn30xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn31xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn31xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn38xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn38xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn38xxp2.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn38xxp2.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn50xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn50xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn52xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn52xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn52xxp1.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn52xxp1.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn56xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn56xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn56xxp1.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn56xxp1.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn58xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn58xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn58xxp1.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn58xxp1.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn63xx.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn63xx.c
  head/sys/contrib/octeon-sdk/cvmx-error-init-cn63xxp1.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error-init-cn63xxp1.c
  head/sys/contrib/octeon-sdk/cvmx-error.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-error.c
  head/sys/contrib/octeon-sdk/cvmx-error.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-error.h
  head/sys/contrib/octeon-sdk/cvmx-fpa-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-fpa-defs.h
  head/sys/contrib/octeon-sdk/cvmx-gmxx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-gmxx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-gpio-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-gpio-defs.h
  head/sys/contrib/octeon-sdk/cvmx-helper-jtag.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-helper-jtag.c
  head/sys/contrib/octeon-sdk/cvmx-helper-jtag.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-helper-jtag.h
  head/sys/contrib/octeon-sdk/cvmx-helper-srio.c
     - copied, changed from r215989, vendor-sys/octeon-sdk/dist/cvmx-helper-srio.c
  head/sys/contrib/octeon-sdk/cvmx-helper-srio.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-helper-srio.h
  head/sys/contrib/octeon-sdk/cvmx-iob-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-iob-defs.h
  head/sys/contrib/octeon-sdk/cvmx-ipd-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-ipd-defs.h
  head/sys/contrib/octeon-sdk/cvmx-ixf18201.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-ixf18201.c
  head/sys/contrib/octeon-sdk/cvmx-ixf18201.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-ixf18201.h
  head/sys/contrib/octeon-sdk/cvmx-key-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-key-defs.h
  head/sys/contrib/octeon-sdk/cvmx-l2c-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-l2c-defs.h
  head/sys/contrib/octeon-sdk/cvmx-l2d-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-l2d-defs.h
  head/sys/contrib/octeon-sdk/cvmx-l2t-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-l2t-defs.h
  head/sys/contrib/octeon-sdk/cvmx-led-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-led-defs.h
  head/sys/contrib/octeon-sdk/cvmx-lmcx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-lmcx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-mio-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-mio-defs.h
  head/sys/contrib/octeon-sdk/cvmx-mixx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-mixx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-mpi-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-mpi-defs.h
  head/sys/contrib/octeon-sdk/cvmx-ndf-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-ndf-defs.h
  head/sys/contrib/octeon-sdk/cvmx-npei-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-npei-defs.h
  head/sys/contrib/octeon-sdk/cvmx-npi-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-npi-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pci-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pci-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pcieepx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pcieepx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pciercx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pciercx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pcm-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pcm-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pcmx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pcmx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pcsx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pcsx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pcsxx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pcsxx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pemx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pemx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pescx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pescx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pexp-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pexp-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pip-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pip-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pko-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pko-defs.h
  head/sys/contrib/octeon-sdk/cvmx-pow-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-pow-defs.h
  head/sys/contrib/octeon-sdk/cvmx-power-throttle.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-power-throttle.c
  head/sys/contrib/octeon-sdk/cvmx-power-throttle.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-power-throttle.h
  head/sys/contrib/octeon-sdk/cvmx-rad-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-rad-defs.h
  head/sys/contrib/octeon-sdk/cvmx-rnm-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-rnm-defs.h
  head/sys/contrib/octeon-sdk/cvmx-shmem.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-shmem.c
  head/sys/contrib/octeon-sdk/cvmx-shmem.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-shmem.h
  head/sys/contrib/octeon-sdk/cvmx-sim-magic.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-sim-magic.h
  head/sys/contrib/octeon-sdk/cvmx-sli-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-sli-defs.h
  head/sys/contrib/octeon-sdk/cvmx-smi-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-smi-defs.h
  head/sys/contrib/octeon-sdk/cvmx-smix-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-smix-defs.h
  head/sys/contrib/octeon-sdk/cvmx-spx0-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-spx0-defs.h
  head/sys/contrib/octeon-sdk/cvmx-spxx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-spxx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-srio.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-srio.c
  head/sys/contrib/octeon-sdk/cvmx-srio.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-srio.h
  head/sys/contrib/octeon-sdk/cvmx-sriomaintx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-sriomaintx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-sriox-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-sriox-defs.h
  head/sys/contrib/octeon-sdk/cvmx-srxx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-srxx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-stxx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-stxx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-tim-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-tim-defs.h
  head/sys/contrib/octeon-sdk/cvmx-tlb.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-tlb.c
  head/sys/contrib/octeon-sdk/cvmx-tlb.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-tlb.h
  head/sys/contrib/octeon-sdk/cvmx-tra-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-tra-defs.h
  head/sys/contrib/octeon-sdk/cvmx-uahcx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-uahcx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-uart.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-uart.c
  head/sys/contrib/octeon-sdk/cvmx-uctlx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-uctlx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-usbcx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-usbcx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-usbd.c
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-usbd.c
  head/sys/contrib/octeon-sdk/cvmx-usbd.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-usbd.h
  head/sys/contrib/octeon-sdk/cvmx-usbnx-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-usbnx-defs.h
  head/sys/contrib/octeon-sdk/cvmx-zip-defs.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-zip-defs.h
  head/sys/contrib/octeon-sdk/octeon-boot-info.h
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/octeon-boot-info.h
Replaced:
  head/sys/contrib/octeon-sdk/cvmx-interrupt-handler.S
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-interrupt-handler.S
  head/sys/contrib/octeon-sdk/cvmx-log-arc.S
     - copied unchanged from r215989, vendor-sys/octeon-sdk/dist/cvmx-log-arc.S
Deleted:
  head/sys/contrib/octeon-sdk/README.txt
  head/sys/contrib/octeon-sdk/cvmx-asx.h
  head/sys/contrib/octeon-sdk/cvmx-ciu.h
  head/sys/contrib/octeon-sdk/cvmx-csr-addresses.h
  head/sys/contrib/octeon-sdk/cvmx-cvmmem.h
  head/sys/contrib/octeon-sdk/cvmx-interrupt-decodes.c
  head/sys/contrib/octeon-sdk/cvmx-interrupt-rsl.c
  head/sys/contrib/octeon-sdk/cvmx-iob.h
  head/sys/contrib/octeon-sdk/cvmx-lmc.h
  head/sys/contrib/octeon-sdk/cvmx-malloc/
  head/sys/contrib/octeon-sdk/cvmx-mio.h
  head/sys/contrib/octeon-sdk/cvmx-resources.config
  head/sys/contrib/octeon-sdk/cvmx-shared-linux-n32.ld
  head/sys/contrib/octeon-sdk/cvmx-shared-linux-o32.ld
  head/sys/contrib/octeon-sdk/cvmx-shared-linux.ld
  head/sys/contrib/octeon-sdk/cvmx-twsi-raw.c
  head/sys/contrib/octeon-sdk/cvmx-twsi-raw.h
  head/sys/contrib/octeon-sdk/cvmx.mk
  head/sys/contrib/octeon-sdk/executive-config.h.template
Modified:
  head/sys/contrib/octeon-sdk/cvmip.h
  head/sys/contrib/octeon-sdk/cvmx-abi.h
  head/sys/contrib/octeon-sdk/cvmx-access-native.h
  head/sys/contrib/octeon-sdk/cvmx-access.h
  head/sys/contrib/octeon-sdk/cvmx-address.h
  head/sys/contrib/octeon-sdk/cvmx-app-init-linux.c
  head/sys/contrib/octeon-sdk/cvmx-app-init.c
  head/sys/contrib/octeon-sdk/cvmx-app-init.h
  head/sys/contrib/octeon-sdk/cvmx-asm.h
  head/sys/contrib/octeon-sdk/cvmx-atomic.h
  head/sys/contrib/octeon-sdk/cvmx-bootloader.h
  head/sys/contrib/octeon-sdk/cvmx-bootmem.c
  head/sys/contrib/octeon-sdk/cvmx-bootmem.h
  head/sys/contrib/octeon-sdk/cvmx-cmd-queue.c
  head/sys/contrib/octeon-sdk/cvmx-cmd-queue.h
  head/sys/contrib/octeon-sdk/cvmx-cn3010-evb-hs5.c
  head/sys/contrib/octeon-sdk/cvmx-cn3010-evb-hs5.h
  head/sys/contrib/octeon-sdk/cvmx-compactflash.c
  head/sys/contrib/octeon-sdk/cvmx-compactflash.h
  head/sys/contrib/octeon-sdk/cvmx-core.c
  head/sys/contrib/octeon-sdk/cvmx-core.h
  head/sys/contrib/octeon-sdk/cvmx-coremask.c
  head/sys/contrib/octeon-sdk/cvmx-coremask.h
  head/sys/contrib/octeon-sdk/cvmx-csr-db-support.c
  head/sys/contrib/octeon-sdk/cvmx-csr-db.c
  head/sys/contrib/octeon-sdk/cvmx-csr-db.h
  head/sys/contrib/octeon-sdk/cvmx-csr-enums.h
  head/sys/contrib/octeon-sdk/cvmx-csr-typedefs.h
  head/sys/contrib/octeon-sdk/cvmx-csr.h
  head/sys/contrib/octeon-sdk/cvmx-dfa.c
  head/sys/contrib/octeon-sdk/cvmx-dfa.h
  head/sys/contrib/octeon-sdk/cvmx-dma-engine.c
  head/sys/contrib/octeon-sdk/cvmx-dma-engine.h
  head/sys/contrib/octeon-sdk/cvmx-ebt3000.c
  head/sys/contrib/octeon-sdk/cvmx-ebt3000.h
  head/sys/contrib/octeon-sdk/cvmx-fau.h
  head/sys/contrib/octeon-sdk/cvmx-flash.c
  head/sys/contrib/octeon-sdk/cvmx-flash.h
  head/sys/contrib/octeon-sdk/cvmx-fpa.c
  head/sys/contrib/octeon-sdk/cvmx-fpa.h
  head/sys/contrib/octeon-sdk/cvmx-gmx.h
  head/sys/contrib/octeon-sdk/cvmx-gpio.h
  head/sys/contrib/octeon-sdk/cvmx-helper-board.c
  head/sys/contrib/octeon-sdk/cvmx-helper-board.h
  head/sys/contrib/octeon-sdk/cvmx-helper-check-defines.h
  head/sys/contrib/octeon-sdk/cvmx-helper-errata.c
  head/sys/contrib/octeon-sdk/cvmx-helper-errata.h
  head/sys/contrib/octeon-sdk/cvmx-helper-fpa.c
  head/sys/contrib/octeon-sdk/cvmx-helper-fpa.h
  head/sys/contrib/octeon-sdk/cvmx-helper-loop.c
  head/sys/contrib/octeon-sdk/cvmx-helper-loop.h
  head/sys/contrib/octeon-sdk/cvmx-helper-npi.c
  head/sys/contrib/octeon-sdk/cvmx-helper-npi.h
  head/sys/contrib/octeon-sdk/cvmx-helper-rgmii.c
  head/sys/contrib/octeon-sdk/cvmx-helper-rgmii.h
  head/sys/contrib/octeon-sdk/cvmx-helper-sgmii.c
  head/sys/contrib/octeon-sdk/cvmx-helper-sgmii.h
  head/sys/contrib/octeon-sdk/cvmx-helper-spi.c
  head/sys/contrib/octeon-sdk/cvmx-helper-spi.h
  head/sys/contrib/octeon-sdk/cvmx-helper-util.c
  head/sys/contrib/octeon-sdk/cvmx-helper-util.h
  head/sys/contrib/octeon-sdk/cvmx-helper-xaui.c
  head/sys/contrib/octeon-sdk/cvmx-helper-xaui.h
  head/sys/contrib/octeon-sdk/cvmx-helper.c
  head/sys/contrib/octeon-sdk/cvmx-helper.h
  head/sys/contrib/octeon-sdk/cvmx-higig.h
  head/sys/contrib/octeon-sdk/cvmx-interrupt.c
  head/sys/contrib/octeon-sdk/cvmx-interrupt.h
  head/sys/contrib/octeon-sdk/cvmx-ipd.h
  head/sys/contrib/octeon-sdk/cvmx-key.h
  head/sys/contrib/octeon-sdk/cvmx-l2c.c
  head/sys/contrib/octeon-sdk/cvmx-l2c.h
  head/sys/contrib/octeon-sdk/cvmx-llm.c
  head/sys/contrib/octeon-sdk/cvmx-llm.h
  head/sys/contrib/octeon-sdk/cvmx-log.c
  head/sys/contrib/octeon-sdk/cvmx-log.h
  head/sys/contrib/octeon-sdk/cvmx-malloc.h
  head/sys/contrib/octeon-sdk/cvmx-mdio.h
  head/sys/contrib/octeon-sdk/cvmx-mgmt-port.c
  head/sys/contrib/octeon-sdk/cvmx-mgmt-port.h
  head/sys/contrib/octeon-sdk/cvmx-nand.c
  head/sys/contrib/octeon-sdk/cvmx-nand.h
  head/sys/contrib/octeon-sdk/cvmx-npi.h
  head/sys/contrib/octeon-sdk/cvmx-packet.h
  head/sys/contrib/octeon-sdk/cvmx-pci.h
  head/sys/contrib/octeon-sdk/cvmx-pcie.c
  head/sys/contrib/octeon-sdk/cvmx-pcie.h
  head/sys/contrib/octeon-sdk/cvmx-pip.h
  head/sys/contrib/octeon-sdk/cvmx-pko.c
  head/sys/contrib/octeon-sdk/cvmx-pko.h
  head/sys/contrib/octeon-sdk/cvmx-platform.h
  head/sys/contrib/octeon-sdk/cvmx-pow.c
  head/sys/contrib/octeon-sdk/cvmx-pow.h
  head/sys/contrib/octeon-sdk/cvmx-raid.c
  head/sys/contrib/octeon-sdk/cvmx-raid.h
  head/sys/contrib/octeon-sdk/cvmx-rng.h
  head/sys/contrib/octeon-sdk/cvmx-rtc.h
  head/sys/contrib/octeon-sdk/cvmx-rwlock.h
  head/sys/contrib/octeon-sdk/cvmx-scratch.h
  head/sys/contrib/octeon-sdk/cvmx-spi.c
  head/sys/contrib/octeon-sdk/cvmx-spi.h
  head/sys/contrib/octeon-sdk/cvmx-spi4000.c
  head/sys/contrib/octeon-sdk/cvmx-spinlock.h
  head/sys/contrib/octeon-sdk/cvmx-swap.h
  head/sys/contrib/octeon-sdk/cvmx-sysinfo.c
  head/sys/contrib/octeon-sdk/cvmx-sysinfo.h
  head/sys/contrib/octeon-sdk/cvmx-thunder.c
  head/sys/contrib/octeon-sdk/cvmx-thunder.h
  head/sys/contrib/octeon-sdk/cvmx-tim.c
  head/sys/contrib/octeon-sdk/cvmx-tim.h
  head/sys/contrib/octeon-sdk/cvmx-tra.c
  head/sys/contrib/octeon-sdk/cvmx-tra.h
  head/sys/contrib/octeon-sdk/cvmx-twsi.c
  head/sys/contrib/octeon-sdk/cvmx-twsi.h
  head/sys/contrib/octeon-sdk/cvmx-uart.h
  head/sys/contrib/octeon-sdk/cvmx-usb.c
  head/sys/contrib/octeon-sdk/cvmx-usb.h
  head/sys/contrib/octeon-sdk/cvmx-utils.h
  head/sys/contrib/octeon-sdk/cvmx-version.h
  head/sys/contrib/octeon-sdk/cvmx-warn.c
  head/sys/contrib/octeon-sdk/cvmx-warn.h
  head/sys/contrib/octeon-sdk/cvmx-wqe.h
  head/sys/contrib/octeon-sdk/cvmx-zip.c
  head/sys/contrib/octeon-sdk/cvmx-zip.h
  head/sys/contrib/octeon-sdk/cvmx-zone.c
  head/sys/contrib/octeon-sdk/cvmx.h
  head/sys/contrib/octeon-sdk/octeon-feature.h
  head/sys/contrib/octeon-sdk/octeon-model.c
  head/sys/contrib/octeon-sdk/octeon-model.h
  head/sys/contrib/octeon-sdk/octeon-pci-console.c
  head/sys/contrib/octeon-sdk/octeon-pci-console.h
  head/sys/mips/cavium/files.octeon1
  head/sys/mips/cavium/octe/ethernet.c
  head/sys/mips/cavium/octe/wrapper-cvmx-includes.h
  head/sys/mips/cavium/octeon_machdep.c
Directory Properties:
  head/sys/contrib/octeon-sdk/   (props changed)

Modified: head/sys/contrib/octeon-sdk/cvmip.h
==============================================================================
--- head/sys/contrib/octeon-sdk/cvmip.h	Sun Nov 28 08:11:05 2010	(r215989)
+++ head/sys/contrib/octeon-sdk/cvmip.h	Sun Nov 28 08:18:16 2010	(r215990)
@@ -1,39 +1,40 @@
 /***********************license start***************
- *  Copyright (c) 2003-2008 Cavium Networks (support at cavium.com). All rights
- *  reserved.
+ * Copyright (c) 2003-2010  Cavium Networks (support at cavium.com). All rights
+ * reserved.
  *
  *
- *  Redistribution and use in source and binary forms, with or without
- *  modification, are permitted provided that the following conditions are
- *  met:
- *
- *      * Redistributions of source code must retain the above copyright
- *        notice, this list of conditions and the following disclaimer.
- *
- *      * Redistributions in binary form must reproduce the above
- *        copyright notice, this list of conditions and the following
- *        disclaimer in the documentation and/or other materials provided
- *        with the distribution.
- *
- *      * Neither the name of Cavium Networks nor the names of
- *        its contributors may be used to endorse or promote products
- *        derived from this software without specific prior written
- *        permission.
- *
- *  TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
- *  AND WITH ALL FAULTS AND CAVIUM NETWORKS MAKES NO PROMISES, REPRESENTATIONS
- *  OR WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH
- *  RESPECT TO THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY
- *  REPRESENTATION OR DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT
- *  DEFECTS, AND CAVIUM SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES
- *  OF TITLE, MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR
- *  PURPOSE, LACK OF VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET
- *  POSSESSION OR CORRESPONDENCE TO DESCRIPTION.  THE ENTIRE RISK ARISING OUT
- *  OF USE OR PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
- *
- *
- *  For any questions regarding licensing please contact marketing at caviumnetworks.com
- *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+
+ *   * Neither the name of Cavium Networks nor the names of
+ *     its contributors may be used to endorse or promote products
+ *     derived from this software without specific prior written
+ *     permission.
+
+ * This Software, including technical data, may be subject to U.S. export  control
+ * laws, including the U.S. Export Administration Act and its  associated
+ * regulations, and may be subject to export or import  regulations in other
+ * countries.
+
+ * TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
+ * AND WITH ALL FAULTS AND CAVIUM  NETWORKS MAKES NO PROMISES, REPRESENTATIONS OR
+ * WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH RESPECT TO
+ * THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY REPRESENTATION OR
+ * DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT DEFECTS, AND CAVIUM
+ * SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES OF TITLE,
+ * MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR PURPOSE, LACK OF
+ * VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET POSSESSION OR
+ * CORRESPONDENCE TO DESCRIPTION. THE ENTIRE  RISK ARISING OUT OF USE OR
+ * PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
  ***********************license end**************************************/
 
 
@@ -41,6 +42,7 @@
 
 
 
+
 /**
  * @file
  *
@@ -48,7 +50,7 @@
  *
  * Definitions for the Internet Protocol (IP) support.
  *
- * <hr>$Revision: 41586 $<hr>
+ * <hr>$Revision: 49448 $<hr>
  *
  */
 

Modified: head/sys/contrib/octeon-sdk/cvmx-abi.h
==============================================================================
--- head/sys/contrib/octeon-sdk/cvmx-abi.h	Sun Nov 28 08:11:05 2010	(r215989)
+++ head/sys/contrib/octeon-sdk/cvmx-abi.h	Sun Nov 28 08:18:16 2010	(r215990)
@@ -1,39 +1,40 @@
 /***********************license start***************
- *  Copyright (c) 2003-2008 Cavium Networks (support at cavium.com). All rights
- *  reserved.
+ * Copyright (c) 2003-2010  Cavium Networks (support at cavium.com). All rights
+ * reserved.
  *
  *
- *  Redistribution and use in source and binary forms, with or without
- *  modification, are permitted provided that the following conditions are
- *  met:
- *
- *      * Redistributions of source code must retain the above copyright
- *        notice, this list of conditions and the following disclaimer.
- *
- *      * Redistributions in binary form must reproduce the above
- *        copyright notice, this list of conditions and the following
- *        disclaimer in the documentation and/or other materials provided
- *        with the distribution.
- *
- *      * Neither the name of Cavium Networks nor the names of
- *        its contributors may be used to endorse or promote products
- *        derived from this software without specific prior written
- *        permission.
- *
- *  TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
- *  AND WITH ALL FAULTS AND CAVIUM NETWORKS MAKES NO PROMISES, REPRESENTATIONS
- *  OR WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH
- *  RESPECT TO THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY
- *  REPRESENTATION OR DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT
- *  DEFECTS, AND CAVIUM SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES
- *  OF TITLE, MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR
- *  PURPOSE, LACK OF VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET
- *  POSSESSION OR CORRESPONDENCE TO DESCRIPTION.  THE ENTIRE RISK ARISING OUT
- *  OF USE OR PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
- *
- *
- *  For any questions regarding licensing please contact marketing at caviumnetworks.com
- *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+
+ *   * Neither the name of Cavium Networks nor the names of
+ *     its contributors may be used to endorse or promote products
+ *     derived from this software without specific prior written
+ *     permission.
+
+ * This Software, including technical data, may be subject to U.S. export  control
+ * laws, including the U.S. Export Administration Act and its  associated
+ * regulations, and may be subject to export or import  regulations in other
+ * countries.
+
+ * TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
+ * AND WITH ALL FAULTS AND CAVIUM  NETWORKS MAKES NO PROMISES, REPRESENTATIONS OR
+ * WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH RESPECT TO
+ * THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY REPRESENTATION OR
+ * DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT DEFECTS, AND CAVIUM
+ * SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES OF TITLE,
+ * MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR PURPOSE, LACK OF
+ * VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET POSSESSION OR
+ * CORRESPONDENCE TO DESCRIPTION. THE ENTIRE  RISK ARISING OUT OF USE OR
+ * PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
  ***********************license end**************************************/
 
 
@@ -41,12 +42,13 @@
 
 
 
+
 /**
  * @file
  *
  * This file defines macros for use in determining the current calling ABI.
  *
- * <hr>$Revision: 41586 $<hr>
+ * <hr>$Revision: 49448 $<hr>
 */
 
 #ifndef __CVMX_ABI_H__

Modified: head/sys/contrib/octeon-sdk/cvmx-access-native.h
==============================================================================
--- head/sys/contrib/octeon-sdk/cvmx-access-native.h	Sun Nov 28 08:11:05 2010	(r215989)
+++ head/sys/contrib/octeon-sdk/cvmx-access-native.h	Sun Nov 28 08:18:16 2010	(r215990)
@@ -1,41 +1,43 @@
 /***********************license start***************
- *  Copyright (c) 2003-2009 Cavium Networks (support at cavium.com). All rights
- *  reserved.
+ * Copyright (c) 2003-2010  Cavium Networks (support at cavium.com). All rights
+ * reserved.
  *
  *
- *  Redistribution and use in source and binary forms, with or without
- *  modification, are permitted provided that the following conditions are
- *  met:
- *
- *      * Redistributions of source code must retain the above copyright
- *        notice, this list of conditions and the following disclaimer.
- *
- *      * Redistributions in binary form must reproduce the above
- *        copyright notice, this list of conditions and the following
- *        disclaimer in the documentation and/or other materials provided
- *        with the distribution.
- *
- *      * Neither the name of Cavium Networks nor the names of
- *        its contributors may be used to endorse or promote products
- *        derived from this software without specific prior written
- *        permission.
- *
- *  TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
- *  AND WITH ALL FAULTS AND CAVIUM NETWORKS MAKES NO PROMISES, REPRESENTATIONS
- *  OR WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH
- *  RESPECT TO THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY
- *  REPRESENTATION OR DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT
- *  DEFECTS, AND CAVIUM SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES
- *  OF TITLE, MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR
- *  PURPOSE, LACK OF VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET
- *  POSSESSION OR CORRESPONDENCE TO DESCRIPTION.  THE ENTIRE RISK ARISING OUT
- *  OF USE OR PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
- *
- *
- *  For any questions regarding licensing please contact marketing at caviumnetworks.com
- *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+
+ *   * Neither the name of Cavium Networks nor the names of
+ *     its contributors may be used to endorse or promote products
+ *     derived from this software without specific prior written
+ *     permission.
+
+ * This Software, including technical data, may be subject to U.S. export  control
+ * laws, including the U.S. Export Administration Act and its  associated
+ * regulations, and may be subject to export or import  regulations in other
+ * countries.
+
+ * TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
+ * AND WITH ALL FAULTS AND CAVIUM  NETWORKS MAKES NO PROMISES, REPRESENTATIONS OR
+ * WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH RESPECT TO
+ * THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY REPRESENTATION OR
+ * DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT DEFECTS, AND CAVIUM
+ * SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES OF TITLE,
+ * MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR PURPOSE, LACK OF
+ * VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET POSSESSION OR
+ * CORRESPONDENCE TO DESCRIPTION. THE ENTIRE  RISK ARISING OUT OF USE OR
+ * PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
  ***********************license end**************************************/
 
+
 /**
  * @file
  * Functions for accessing memory and CSRs on Octeon when we are compiling
@@ -81,9 +83,24 @@ static inline uint64_t cvmx_ptr_to_phys(
         cvmx_warn_if(ptr==NULL, "cvmx_ptr_to_phys() passed a NULL pointer\n");
 
 #ifdef CVMX_BUILD_FOR_UBOOT
-    /* U-boot is a special case, as it is running in error level, which disables the TLB completely.
-    ** U-boot may use kseg0 addresses, or may directly use physical addresses already */
-    return(CAST64(ptr) & 0x7FFFFFFF);
+    uint64_t uboot_tlb_ptr_to_phys(void *ptr);
+
+    if (((uint32_t)ptr) < 0x80000000)
+    {
+        /* Handle useg (unmapped due to ERL) here*/
+        return(CAST64(ptr) & 0x7FFFFFFF);
+    }
+    else if (((uint32_t)ptr) < 0xC0000000)
+    {
+        /* Here we handle KSEG0/KSEG1 _pointers_.  We know we are dealing
+        ** with 32 bit only values, so we treat them that way.  Note that
+        ** a cvmx_phys_to_ptr(cvmx_ptr_to_phys(X)) will not return X in this case,
+        ** but the physical address of the KSEG0/KSEG1 address. */
+        return(CAST64(ptr) & 0x1FFFFFFF);
+    }
+    else
+        return(uboot_tlb_ptr_to_phys(ptr));   /* Should not get get here in !TLB case */
+
 #endif
 
 #ifdef __linux__
@@ -166,14 +183,49 @@ static inline void *cvmx_phys_to_ptr(uin
         cvmx_warn_if(physical_address==0, "cvmx_phys_to_ptr() passed a zero address\n");
 
 #ifdef CVMX_BUILD_FOR_UBOOT
-    /* U-boot is a special case, as it is running in error level, which disables the TLB completely.
-    ** U-boot may use kseg0 addresses, or may directly use physical addresses already */
+#if !CONFIG_OCTEON_UBOOT_TLB
     if (physical_address >= 0x80000000)
         return NULL;
     else
         return CASTPTR(void, (physical_address & 0x7FFFFFFF));
 #endif
 
+    /* U-boot is a special case, as it is running in 32 bit mode, using the TLB to map code/data
+    ** which can have a physical address above the 32 bit address space.  1-1 mappings are used
+    ** to allow the low 2 GBytes to be accessed as in error level.
+    **
+    ** NOTE:  This conversion can cause problems in u-boot, as users may want to enter addresses
+    ** like 0xBFC00000 (kseg1 boot bus address), which is a valid 64 bit physical address,
+    ** but is likely intended to be a boot bus address. */
+
+    if (physical_address < 0x80000000)
+    {
+        /* Handle useg here.  ERL is set, so useg is unmapped.  This is the only physical
+        ** address range that is directly addressable by u-boot. */
+        return CASTPTR(void, physical_address);
+    }
+    else
+    {
+	DECLARE_GLOBAL_DATA_PTR;
+        extern char uboot_start;
+        /* Above 0x80000000 we can only support one case - a physical address
+        ** that is mapped for u-boot code/data.  We check against the u-boot mem range,
+        ** and return NULL if it is out of this range.
+        */
+        if (physical_address >= gd->bd->bi_uboot_ram_addr
+            && physical_address < gd->bd->bi_uboot_ram_addr + gd->bd->bi_uboot_ram_used_size)
+        {
+            return ((char *)&uboot_start + (physical_address - gd->bd->bi_uboot_ram_addr));
+        }
+        else
+            return(NULL);
+    }
+
+    if (physical_address >= 0x80000000)
+        return NULL;
+    else
+#endif
+
 #ifdef __linux__
     if (sizeof(void*) == 8)
     {
@@ -199,7 +251,8 @@ static inline void *cvmx_phys_to_ptr(uin
         2nd 256MB is mapped at 0x10000000 and the rest of memory is 1:1 */
     if ((physical_address >= 0x10000000) && (physical_address < 0x20000000))
         return CASTPTR(void, CVMX_ADD_SEG32(CVMX_MIPS32_SPACE_KSEG0, physical_address));
-    else if ((physical_address >= 0x410000000ull) && (physical_address < 0x420000000ull))
+    else if (!OCTEON_IS_MODEL(OCTEON_CN6XXX) && (physical_address >= 0x410000000ull) &&
+                                                       (physical_address < 0x420000000ull))
         return CASTPTR(void, physical_address - 0x400000000ull);
     else
         return CASTPTR(void, physical_address);
@@ -464,7 +517,7 @@ static inline void cvmx_write_csr(uint64
     /* Perform an immediate read after every write to an RSL register to force
         the write to complete. It doesn't matter what RSL read we do, so we
         choose CVMX_MIO_BOOT_BIST_STAT because it is fast and harmless */
-    if ((csr_addr >> 40) == (0x800118))
+    if (((csr_addr >> 40) & 0x7ffff) == (0x118))
         cvmx_read64_uint64(CVMX_MIO_BOOT_BIST_STAT);
 }
 
@@ -503,7 +556,7 @@ static inline void cvmx_read_csr_async(u
 
 
 /**
- * Number of the Core on which the program is currently running. 
+ * Number of the Core on which the program is currently running.
  *
  * @return Number of cores
  */
@@ -548,53 +601,36 @@ static inline int cvmx_dpop(uint64_t val
 
 
 /**
- * Provide current cycle counter as a return value
+ * @deprecated
+ * Provide current cycle counter as a return value. Deprecated, use
+ * cvmx_clock_get_count(CVMX_CLOCK_CORE) to get cycle counter.
  *
  * @return current cycle counter
  */
 static inline uint64_t cvmx_get_cycle(void)
 {
-#if defined(CVMX_ABI_O32)
-    uint32_t tmp_low, tmp_hi;
-
-    asm volatile (
-               "   .set push                    \n"
-               "   .set mips64r2                \n"
-               "   .set noreorder               \n"
-               "   rdhwr %[tmpl], $31           \n"
-               "   dsrl  %[tmph], %[tmpl], 32   \n"
-               "   sll   %[tmpl], 0             \n"
-               "   sll   %[tmph], 0             \n"
-               "   .set pop                 \n"
-                  : [tmpl] "=&r" (tmp_low), [tmph] "=&r" (tmp_hi) : );
-
-    return(((uint64_t)tmp_hi << 32) + tmp_low);
-#else
-    uint64_t cycle;
-    CVMX_RDHWR(cycle, 31);
-    return(cycle);
-#endif
+    return cvmx_clock_get_count(CVMX_CLOCK_CORE);
 }
 
 
 /**
- * Reads a chip global cycle counter.  This counts CPU cycles since
- * chip reset.  The counter is 64 bit.
- * This register does not exist on CN38XX pass 1 silicion
+ * @deprecated
+ * Reads a chip global cycle counter.  This counts SCLK cycles since
+ * chip reset.  The counter is 64 bit. This function is deprecated as the rate
+ * of the global cycle counter is different between Octeon+ and Octeon2, use
+ * cvmx_clock_get_count(CVMX_CLOCK_SCLK) instead. For Octeon2, the clock rate
+ * of SCLK may be differnet than the core clock.
  *
  * @return Global chip cycle count since chip reset.
  */
 static inline uint64_t cvmx_get_cycle_global(void)
 {
-    if (OCTEON_IS_MODEL(OCTEON_CN38XX_PASS1))
-        return 0;
-    else
-        return cvmx_read64_uint64(CVMX_IPD_CLK_COUNT);
+    return cvmx_clock_get_count(CVMX_CLOCK_IPD);
 }
 
 
 /**
- * Wait for the specified number of cycle
+ * Wait for the specified number of core clock cycles
  *
  * @param cycles
  */
@@ -616,7 +652,7 @@ static inline void cvmx_wait(uint64_t cy
  */
 static inline void cvmx_wait_usec(uint64_t usec)
 {
-    uint64_t done = cvmx_get_cycle() + usec * cvmx_sysinfo_get()->cpu_clock_hz / 1000000;
+    uint64_t done = cvmx_get_cycle() + usec * cvmx_clock_get_rate(CVMX_CLOCK_CORE) / 1000000;
     while (cvmx_get_cycle() < done)
     {
         /* Spin */
@@ -625,6 +661,22 @@ static inline void cvmx_wait_usec(uint64
 
 
 /**
+ * Wait for the specified number of io clock cycles
+ *
+ * @param cycles
+ */
+static inline void cvmx_wait_io(uint64_t cycles)
+{
+    uint64_t done = cvmx_clock_get_count(CVMX_CLOCK_SCLK) + cycles;
+
+    while (cvmx_clock_get_count(CVMX_CLOCK_SCLK) < done)
+    {
+        /* Spin */
+    }
+}
+
+
+/**
  * Perform a soft reset of Octeon
  *
  * @return

Modified: head/sys/contrib/octeon-sdk/cvmx-access.h
==============================================================================
--- head/sys/contrib/octeon-sdk/cvmx-address.h	Sun Nov 28 08:11:05 2010	(r215989)
+++ head/sys/contrib/octeon-sdk/cvmx-address.h	Sun Nov 28 08:18:16 2010	(r215990)
@@ -1,41 +1,43 @@
 /***********************license start***************
- *  Copyright (c) 2003-2009 Cavium Networks (support at cavium.com). All rights
- *  reserved.
+ * Copyright (c) 2003-2010  Cavium Networks (support at cavium.com). All rights
+ * reserved.
  *
  *
- *  Redistribution and use in source and binary forms, with or without
- *  modification, are permitted provided that the following conditions are
- *  met:
- *
- *      * Redistributions of source code must retain the above copyright
- *        notice, this list of conditions and the following disclaimer.
- *
- *      * Redistributions in binary form must reproduce the above
- *        copyright notice, this list of conditions and the following
- *        disclaimer in the documentation and/or other materials provided
- *        with the distribution.
- *
- *      * Neither the name of Cavium Networks nor the names of
- *        its contributors may be used to endorse or promote products
- *        derived from this software without specific prior written
- *        permission.
- *
- *  TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
- *  AND WITH ALL FAULTS AND CAVIUM NETWORKS MAKES NO PROMISES, REPRESENTATIONS
- *  OR WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH
- *  RESPECT TO THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY
- *  REPRESENTATION OR DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT
- *  DEFECTS, AND CAVIUM SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES
- *  OF TITLE, MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR
- *  PURPOSE, LACK OF VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET
- *  POSSESSION OR CORRESPONDENCE TO DESCRIPTION.  THE ENTIRE RISK ARISING OUT
- *  OF USE OR PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
- *
- *
- *  For any questions regarding licensing please contact marketing at caviumnetworks.com
- *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+
+ *   * Neither the name of Cavium Networks nor the names of
+ *     its contributors may be used to endorse or promote products
+ *     derived from this software without specific prior written
+ *     permission.
+
+ * This Software, including technical data, may be subject to U.S. export  control
+ * laws, including the U.S. Export Administration Act and its  associated
+ * regulations, and may be subject to export or import  regulations in other
+ * countries.
+
+ * TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
+ * AND WITH ALL FAULTS AND CAVIUM  NETWORKS MAKES NO PROMISES, REPRESENTATIONS OR
+ * WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH RESPECT TO
+ * THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY REPRESENTATION OR
+ * DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT DEFECTS, AND CAVIUM
+ * SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES OF TITLE,
+ * MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR PURPOSE, LACK OF
+ * VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET POSSESSION OR
+ * CORRESPONDENCE TO DESCRIPTION. THE ENTIRE  RISK ARISING OUT OF USE OR
+ * PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
  ***********************license end**************************************/
 
+
 /**
  * @file
  * Typedefs and defines for working with Octeon physical addresses.
@@ -63,29 +65,27 @@ typedef enum {
    CVMX_MIPS_XKSEG_SPACE_KSEG3 = 3LL
 } cvmx_mips_xkseg_space_t;
 
-// decodes <14:13> of a kseg3 window address
+  /* decodes <14:13> of a kseg3 window address */
 typedef enum {
    CVMX_ADD_WIN_SCR = 0L,
-   CVMX_ADD_WIN_DMA = 1L,   // see cvmx_add_win_dma_dec_t for further decode
+   CVMX_ADD_WIN_DMA = 1L,   /* see cvmx_add_win_dma_dec_t for further decode */
    CVMX_ADD_WIN_UNUSED = 2L,
    CVMX_ADD_WIN_UNUSED2 = 3L
 } cvmx_add_win_dec_t;
 
-// decode within DMA space
+  /* decode within DMA space */
 typedef enum {
-   CVMX_ADD_WIN_DMA_ADD = 0L,     // add store data to the write buffer entry, allocating it if necessary
-   CVMX_ADD_WIN_DMA_SENDMEM = 1L, // send out the write buffer entry to DRAM
-                                     // store data must be normal DRAM memory space address in this case
-   CVMX_ADD_WIN_DMA_SENDDMA = 2L, // send out the write buffer entry as an IOBDMA command
-                                     // see CVMX_ADD_WIN_DMA_SEND_DEC for data contents
-   CVMX_ADD_WIN_DMA_SENDIO = 3L,  // send out the write buffer entry as an IO write
-                                     // store data must be normal IO space address in this case
-   CVMX_ADD_WIN_DMA_SENDSINGLE = 4L, // send out a single-tick command on the NCB bus
-                                        // no write buffer data needed/used
+   CVMX_ADD_WIN_DMA_ADD = 0L,     /* add store data to the write buffer entry, allocating it if necessary */
+   CVMX_ADD_WIN_DMA_SENDMEM = 1L, /* send out the write buffer entry to DRAM */
+   /* store data must be normal DRAM memory space address in this case */
+   CVMX_ADD_WIN_DMA_SENDDMA = 2L, /* send out the write buffer entry as an IOBDMA command */
+   /* see CVMX_ADD_WIN_DMA_SEND_DEC for data contents */
+   CVMX_ADD_WIN_DMA_SENDIO = 3L,  /* send out the write buffer entry as an IO write */
+   /* store data must be normal IO space address in this case */
+   CVMX_ADD_WIN_DMA_SENDSINGLE = 4L, /* send out a single-tick command on the NCB bus */
+   /* no write buffer data needed/used */
 } cvmx_add_win_dma_dec_t;
 
-
-
 /**
  *   Physical Address Decode
  *
@@ -116,63 +116,63 @@ typedef union {
    struct {
       cvmx_mips_space_t          R   : 2;
       uint64_t               offset :62;
-   } sva; // mapped or unmapped virtual address
+   } sva; /* mapped or unmapped virtual address */
 
    struct {
       uint64_t               zeroes :33;
       uint64_t               offset :31;
-   } suseg; // mapped USEG virtual addresses (typically)
+   } suseg; /* mapped USEG virtual addresses (typically) */
 
    struct {
       uint64_t                ones  :33;
       cvmx_mips_xkseg_space_t   sp   : 2;
       uint64_t               offset :29;
-   } sxkseg; // mapped or unmapped virtual address
+   } sxkseg; /* mapped or unmapped virtual address */
 
    struct {
-      cvmx_mips_space_t          R   : 2; // CVMX_MIPS_SPACE_XKPHYS in this case
-      uint64_t                 cca  : 3; // ignored by octeon
+      cvmx_mips_space_t          R   : 2; /* CVMX_MIPS_SPACE_XKPHYS in this case */
+      uint64_t                 cca  : 3; /* ignored by octeon */
       uint64_t                 mbz  :10;
-      uint64_t                  pa  :49; // physical address
-   } sxkphys; // physical address accessed through xkphys unmapped virtual address
+      uint64_t                  pa  :49; /* physical address */
+   } sxkphys; /* physical address accessed through xkphys unmapped virtual address */
 
    struct {
       uint64_t                 mbz  :15;
-      uint64_t                is_io : 1; // if set, the address is uncached and resides on MCB bus
-      uint64_t                 did  : 8; // the hardware ignores this field when is_io==0, else device ID
-      uint64_t                unaddr: 4; // the hardware ignores <39:36> in Octeon I
+      uint64_t                is_io : 1; /* if set, the address is uncached and resides on MCB bus */
+      uint64_t                 did  : 8; /* the hardware ignores this field when is_io==0, else device ID */
+      uint64_t                unaddr: 4; /* the hardware ignores <39:36> in Octeon I */
       uint64_t               offset :36;
-   } sphys; // physical address
+   } sphys; /* physical address */
 
    struct {
-      uint64_t               zeroes :24; // techically, <47:40> are dont-cares
-      uint64_t                unaddr: 4; // the hardware ignores <39:36> in Octeon I
+      uint64_t               zeroes :24; /* techically, <47:40> are dont-cares */
+      uint64_t                unaddr: 4; /* the hardware ignores <39:36> in Octeon I */
       uint64_t               offset :36;
-   } smem; // physical mem address
+   } smem; /* physical mem address */
 
    struct {
       uint64_t                 mem_region  :2;
       uint64_t                 mbz  :13;
-      uint64_t                is_io : 1; // 1 in this case
-      uint64_t                 did  : 8; // the hardware ignores this field when is_io==0, else device ID
-      uint64_t                unaddr: 4; // the hardware ignores <39:36> in Octeon I
+      uint64_t                is_io : 1; /* 1 in this case */
+      uint64_t                 did  : 8; /* the hardware ignores this field when is_io==0, else device ID */
+      uint64_t                unaddr: 4; /* the hardware ignores <39:36> in Octeon I */
       uint64_t               offset :36;
-   } sio; // physical IO address
+   } sio; /* physical IO address */
 
    struct {
       uint64_t                ones   : 49;
-      cvmx_add_win_dec_t   csrdec : 2;    // CVMX_ADD_WIN_SCR (0) in this case
+      cvmx_add_win_dec_t   csrdec : 2;    /* CVMX_ADD_WIN_SCR (0) in this case */
       uint64_t                addr   : 13;
-   } sscr; // scratchpad virtual address - accessed through a window at the end of kseg3
+   } sscr; /* scratchpad virtual address - accessed through a window at the end of kseg3 */
 
-   // there should only be stores to IOBDMA space, no loads
+   /* there should only be stores to IOBDMA space, no loads */
    struct {
       uint64_t                ones   : 49;
-      cvmx_add_win_dec_t   csrdec : 2;    // CVMX_ADD_WIN_DMA (1) in this case
+      cvmx_add_win_dec_t   csrdec : 2;    /* CVMX_ADD_WIN_DMA (1) in this case */
       uint64_t                unused2: 3;
       cvmx_add_win_dma_dec_t type : 3;
       uint64_t                addr   : 7;
-   } sdma; // IOBDMA virtual address - accessed through a window at the end of kseg3
+   } sdma; /* IOBDMA virtual address - accessed through a window at the end of kseg3 */
 
    struct {
       uint64_t                didspace : 24;
@@ -203,8 +203,8 @@ typedef union {
 #define CVMX_FULL_DID(did,subdid)           (((did) << 3) | (subdid))
 
 
-// from include/ncb_rsl_id.v
-#define CVMX_OCT_DID_MIS 0ULL   // misc stuff
+   /* from include/ncb_rsl_id.v */
+#define CVMX_OCT_DID_MIS 0ULL   /* misc stuff */
 #define CVMX_OCT_DID_GMX0 1ULL
 #define CVMX_OCT_DID_GMX1 2ULL
 #define CVMX_OCT_DID_PCI 3ULL
@@ -217,7 +217,7 @@ typedef union {
 #define CVMX_OCT_DID_PKT 10ULL
 #define CVMX_OCT_DID_TIM 11ULL
 #define CVMX_OCT_DID_TAG 12ULL
-// the rest are not on the IO bus
+   /* the rest are not on the IO bus */
 #define CVMX_OCT_DID_L2C 16ULL
 #define CVMX_OCT_DID_LMC 17ULL
 #define CVMX_OCT_DID_SPX0 18ULL

Copied: head/sys/contrib/octeon-sdk/cvmx-agl-defs.h (from r215989, vendor-sys/octeon-sdk/dist/cvmx-agl-defs.h)
==============================================================================
--- /dev/null	00:00:00 1970	(empty, because file is newly added)
+++ head/sys/contrib/octeon-sdk/cvmx-agl-defs.h	Sun Nov 28 08:18:16 2010	(r215990, copy of r215989, vendor-sys/octeon-sdk/dist/cvmx-agl-defs.h)
@@ -0,0 +1,4615 @@
+/***********************license start***************
+ * Copyright (c) 2003-2010  Cavium Networks (support at cavium.com). All rights
+ * reserved.
+ *
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+
+ *   * Neither the name of Cavium Networks nor the names of
+ *     its contributors may be used to endorse or promote products
+ *     derived from this software without specific prior written
+ *     permission.
+
+ * This Software, including technical data, may be subject to U.S. export  control
+ * laws, including the U.S. Export Administration Act and its  associated
+ * regulations, and may be subject to export or import  regulations in other
+ * countries.
+
+ * TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
+ * AND WITH ALL FAULTS AND CAVIUM  NETWORKS MAKES NO PROMISES, REPRESENTATIONS OR
+ * WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH RESPECT TO
+ * THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY REPRESENTATION OR
+ * DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT DEFECTS, AND CAVIUM
+ * SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES OF TITLE,
+ * MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR PURPOSE, LACK OF
+ * VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET POSSESSION OR
+ * CORRESPONDENCE TO DESCRIPTION. THE ENTIRE  RISK ARISING OUT OF USE OR
+ * PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
+ ***********************license end**************************************/
+
+
+/**
+ * cvmx-agl-defs.h
+ *
+ * Configuration and status register (CSR) type definitions for
+ * Octeon agl.
+ *
+ * This file is auto generated. Do not edit.
+ *
+ * <hr>$Revision$<hr>
+ *
+ */
+#ifndef __CVMX_AGL_TYPEDEFS_H__
+#define __CVMX_AGL_TYPEDEFS_H__
+
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+#define CVMX_AGL_GMX_BAD_REG CVMX_AGL_GMX_BAD_REG_FUNC()
+static inline uint64_t CVMX_AGL_GMX_BAD_REG_FUNC(void)
+{
+	if (!(OCTEON_IS_MODEL(OCTEON_CN52XX) || OCTEON_IS_MODEL(OCTEON_CN56XX) || OCTEON_IS_MODEL(OCTEON_CN63XX)))
+		cvmx_warn("CVMX_AGL_GMX_BAD_REG not supported on this chip\n");
+	return CVMX_ADD_IO_SEG(0x00011800E0000518ull);
+}
+#else
+#define CVMX_AGL_GMX_BAD_REG (CVMX_ADD_IO_SEG(0x00011800E0000518ull))
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+#define CVMX_AGL_GMX_BIST CVMX_AGL_GMX_BIST_FUNC()
+static inline uint64_t CVMX_AGL_GMX_BIST_FUNC(void)
+{
+	if (!(OCTEON_IS_MODEL(OCTEON_CN52XX) || OCTEON_IS_MODEL(OCTEON_CN56XX) || OCTEON_IS_MODEL(OCTEON_CN63XX)))
+		cvmx_warn("CVMX_AGL_GMX_BIST not supported on this chip\n");
+	return CVMX_ADD_IO_SEG(0x00011800E0000400ull);
+}
+#else
+#define CVMX_AGL_GMX_BIST (CVMX_ADD_IO_SEG(0x00011800E0000400ull))
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+#define CVMX_AGL_GMX_DRV_CTL CVMX_AGL_GMX_DRV_CTL_FUNC()
+static inline uint64_t CVMX_AGL_GMX_DRV_CTL_FUNC(void)
+{
+	if (!(OCTEON_IS_MODEL(OCTEON_CN52XX) || OCTEON_IS_MODEL(OCTEON_CN56XX)))
+		cvmx_warn("CVMX_AGL_GMX_DRV_CTL not supported on this chip\n");
+	return CVMX_ADD_IO_SEG(0x00011800E00007F0ull);
+}
+#else
+#define CVMX_AGL_GMX_DRV_CTL (CVMX_ADD_IO_SEG(0x00011800E00007F0ull))
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+#define CVMX_AGL_GMX_INF_MODE CVMX_AGL_GMX_INF_MODE_FUNC()
+static inline uint64_t CVMX_AGL_GMX_INF_MODE_FUNC(void)
+{
+	if (!(OCTEON_IS_MODEL(OCTEON_CN52XX) || OCTEON_IS_MODEL(OCTEON_CN56XX)))
+		cvmx_warn("CVMX_AGL_GMX_INF_MODE not supported on this chip\n");
+	return CVMX_ADD_IO_SEG(0x00011800E00007F8ull);
+}
+#else
+#define CVMX_AGL_GMX_INF_MODE (CVMX_ADD_IO_SEG(0x00011800E00007F8ull))
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+static inline uint64_t CVMX_AGL_GMX_PRTX_CFG(unsigned long offset)
+{
+	if (!(
+	      (OCTEON_IS_MODEL(OCTEON_CN52XX) && ((offset <= 1))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN56XX) && ((offset == 0))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN63XX) && ((offset <= 1)))))
+		cvmx_warn("CVMX_AGL_GMX_PRTX_CFG(%lu) is invalid on this chip\n", offset);
+	return CVMX_ADD_IO_SEG(0x00011800E0000010ull) + ((offset) & 1) * 2048;
+}
+#else
+#define CVMX_AGL_GMX_PRTX_CFG(offset) (CVMX_ADD_IO_SEG(0x00011800E0000010ull) + ((offset) & 1) * 2048)
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+static inline uint64_t CVMX_AGL_GMX_RXX_ADR_CAM0(unsigned long offset)
+{
+	if (!(
+	      (OCTEON_IS_MODEL(OCTEON_CN52XX) && ((offset <= 1))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN56XX) && ((offset == 0))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN63XX) && ((offset <= 1)))))
+		cvmx_warn("CVMX_AGL_GMX_RXX_ADR_CAM0(%lu) is invalid on this chip\n", offset);
+	return CVMX_ADD_IO_SEG(0x00011800E0000180ull) + ((offset) & 1) * 2048;
+}
+#else
+#define CVMX_AGL_GMX_RXX_ADR_CAM0(offset) (CVMX_ADD_IO_SEG(0x00011800E0000180ull) + ((offset) & 1) * 2048)
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+static inline uint64_t CVMX_AGL_GMX_RXX_ADR_CAM1(unsigned long offset)
+{
+	if (!(
+	      (OCTEON_IS_MODEL(OCTEON_CN52XX) && ((offset <= 1))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN56XX) && ((offset == 0))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN63XX) && ((offset <= 1)))))
+		cvmx_warn("CVMX_AGL_GMX_RXX_ADR_CAM1(%lu) is invalid on this chip\n", offset);
+	return CVMX_ADD_IO_SEG(0x00011800E0000188ull) + ((offset) & 1) * 2048;
+}
+#else
+#define CVMX_AGL_GMX_RXX_ADR_CAM1(offset) (CVMX_ADD_IO_SEG(0x00011800E0000188ull) + ((offset) & 1) * 2048)
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+static inline uint64_t CVMX_AGL_GMX_RXX_ADR_CAM2(unsigned long offset)
+{
+	if (!(
+	      (OCTEON_IS_MODEL(OCTEON_CN52XX) && ((offset <= 1))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN56XX) && ((offset == 0))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN63XX) && ((offset <= 1)))))
+		cvmx_warn("CVMX_AGL_GMX_RXX_ADR_CAM2(%lu) is invalid on this chip\n", offset);
+	return CVMX_ADD_IO_SEG(0x00011800E0000190ull) + ((offset) & 1) * 2048;
+}
+#else
+#define CVMX_AGL_GMX_RXX_ADR_CAM2(offset) (CVMX_ADD_IO_SEG(0x00011800E0000190ull) + ((offset) & 1) * 2048)
+#endif
+#if CVMX_ENABLE_CSR_ADDRESS_CHECKING
+static inline uint64_t CVMX_AGL_GMX_RXX_ADR_CAM3(unsigned long offset)
+{
+	if (!(
+	      (OCTEON_IS_MODEL(OCTEON_CN52XX) && ((offset <= 1))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN56XX) && ((offset == 0))) ||
+	      (OCTEON_IS_MODEL(OCTEON_CN63XX) && ((offset <= 1)))))
+		cvmx_warn("CVMX_AGL_GMX_RXX_ADR_CAM3(%lu) is invalid on this chip\n", offset);
+	return CVMX_ADD_IO_SEG(0x00011800E0000198ull) + ((offset) & 1) * 2048;
+}
+#else
+#define CVMX_AGL_GMX_RXX_ADR_CAM3(offset) (CVMX_ADD_IO_SEG(0x00011800E0000198ull) + ((offset) & 1) * 2048)
+#endif

*** DIFF OUTPUT TRUNCATED AT 1000 LINES ***


More information about the svn-src-head mailing list
--- head/sys/contrib/octeon-sdk/cvmx-access.h	Sun Nov 28 08:11:05 2010	(r215989)
+++ head/sys/contrib/octeon-sdk/cvmx-access.h	Sun Nov 28 08:18:16 2010	(r215990)
@@ -1,41 +1,43 @@
 /***********************license start***************
- *  Copyright (c) 2003-2009 Cavium Networks (support at cavium.com). All rights
- *  reserved.
+ * Copyright (c) 2003-2010  Cavium Networks (support at cavium.com). All rights
+ * reserved.
  *
  *
- *  Redistribution and use in source and binary forms, with or without
- *  modification, are permitted provided that the following conditions are
- *  met:
- *
- *      * Redistributions of source code must retain the above copyright
- *        notice, this list of conditions and the following disclaimer.
- *
- *      * Redistributions in binary form must reproduce the above
- *        copyright notice, this list of conditions and the following
- *        disclaimer in the documentation and/or other materials provided
- *        with the distribution.
- *
- *      * Neither the name of Cavium Networks nor the names of
- *        its contributors may be used to endorse or promote products
- *        derived from this software without specific prior written
- *        permission.
- *
- *  TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
- *  AND WITH ALL FAULTS AND CAVIUM NETWORKS MAKES NO PROMISES, REPRESENTATIONS
- *  OR WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH
- *  RESPECT TO THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY
- *  REPRESENTATION OR DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT
- *  DEFECTS, AND CAVIUM SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES
- *  OF TITLE, MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR
- *  PURPOSE, LACK OF VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET
- *  POSSESSION OR CORRESPONDENCE TO DESCRIPTION.  THE ENTIRE RISK ARISING OUT
- *  OF USE OR PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
- *
- *
- *  For any questions regarding licensing please contact marketing at caviumnetworks.com
- *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+
+ *   * Neither the name of Cavium Networks nor the names of
+ *     its contributors may be used to endorse or promote products
+ *     derived from this software without specific prior written
+ *     permission.
+
+ * This Software, including technical data, may be subject to U.S. export  control
+ * laws, including the U.S. Export Administration Act and its  associated
+ * regulations, and may be subject to export or import  regulations in other
+ * countries.
+
+ * TO THE MAXIMUM EXTENT PERMITTED BY LAW, THE SOFTWARE IS PROVIDED "AS IS"
+ * AND WITH ALL FAULTS AND CAVIUM  NETWORKS MAKES NO PROMISES, REPRESENTATIONS OR
+ * WARRANTIES, EITHER EXPRESS, IMPLIED, STATUTORY, OR OTHERWISE, WITH RESPECT TO
+ * THE SOFTWARE, INCLUDING ITS CONDITION, ITS CONFORMITY TO ANY REPRESENTATION OR
+ * DESCRIPTION, OR THE EXISTENCE OF ANY LATENT OR PATENT DEFECTS, AND CAVIUM
+ * SPECIFICALLY DISCLAIMS ALL IMPLIED (IF ANY) WARRANTIES OF TITLE,
+ * MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR A PARTICULAR PURPOSE, LACK OF
+ * VIRUSES, ACCURACY OR COMPLETENESS, QUIET ENJOYMENT, QUIET POSSESSION OR
+ * CORRESPONDENCE TO DESCRIPTION. THE ENTIRE  RISK ARISING OUT OF USE OR
+ * PERFORMANCE OF THE SOFTWARE LIES WITH YOU.
  ***********************license end**************************************/
 
+
 /**
  * @file
  * Function prototypes for accessing memory and CSRs on Octeon.
@@ -138,7 +140,7 @@ CVMX_FUNCTION void cvmx_send_single(uint
 CVMX_FUNCTION void cvmx_read_csr_async(uint64_t scraddr, uint64_t csr_addr);
 
 /**
- * Number of the Core on which the program is currently running. 
+ * Number of the Core on which the program is currently running.
  *
  * @return Number of cores
  */
@@ -165,23 +167,28 @@ CVMX_FUNCTION uint32_t cvmx_pop(uint32_t
 CVMX_FUNCTION int cvmx_dpop(uint64_t val);
 
 /**
- * Provide current cycle counter as a return value
+ * @deprecated
+ * Provide current cycle counter as a return value. Deprecated, use
+ * cvmx_clock_get_count(CVMX_CLOCK_CORE) to get cycle counter.
  *
  * @return current cycle counter
  */
 CVMX_FUNCTION uint64_t cvmx_get_cycle(void);
 
 /**
- * Reads a chip global cycle counter.  This counts CPU cycles since
- * chip reset.  The counter is 64 bit.
- * This register does not exist on CN38XX pass 1 silicion
+ * @deprecated
+ * Reads a chip global cycle counter.  This counts SCLK cycles since
+ * chip reset.  The counter is 64 bit. This function is deprecated as the rate
+ * of the global cycle counter is different between Octeon+ and Octeon2, use
+ * cvmx_clock_get_count(CVMX_CLOCK_SCLK) instead. For Octeon2, the clock rate
+ * of SCLK may be differnet than the core clock.
  *
  * @return Global chip cycle count since chip reset.
  */
-CVMX_FUNCTION uint64_t cvmx_get_cycle_global(void);
+CVMX_FUNCTION uint64_t cvmx_get_cycle_global(void) __attribute__((deprecated));
 
 /**
  * Wait for the specified number of cycle
  *
  * @param cycles
  */
@@ -195,6 +202,13 @@ CVMX_FUNCTION void cvmx_wait(uint64_t cy
 CVMX_FUNCTION void cvmx_wait_usec(uint64_t usec);
 
 /**
+ * Wait for the specified number of io clock cycles
+ *
+ * @param cycles
+ */
+CVMX_FUNCTION void cvmx_wait_io(uint64_t cycles);
+
+/**
  * Perform a soft reset of Octeon
  *
  * @return
@@ -165,23 +167,28 @@ CVMX_FUNCTION uint32_t cvmx_pop(uint32_t
 
 /**
- * Wait for the specified number of cycle
+ * Wait for the specified number of core clock cycles
  *
  * @param cycles

Modified: head/sys/contrib/octeon-sdk/cvmx-address.h
==============================================================================